MethodChannelGeohawk class

Inheritance

Constructors

MethodChannelGeohawk()

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
onLocationUpdate Stream<LocationFix>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isRunning() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAutoStartSettings() Future<bool>
override
pendingCacheCount() Future<int>
override
requestBatteryOptimizationExemption() Future<void>
override
start({required Duration interval, required Duration maxInterval, required double distanceFilterMeters, required String sendUrl, required String tokenUrl, required String id, Map<String, dynamic> payload = const {}, String? notificationTitle, String? notificationText, String? notificationIcon}) Future<bool>
override
stop() Future<void>
override
syncNow({String id = '', Map<String, dynamic> payload = const {}}) Future<bool>
override
toString() String
A string representation of this object.
inherited
updateNotification({String? title, String? text, String? icon}) Future<bool>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited