GeohawkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • GeohawkPlatform
Implementers

Constructors

GeohawkPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
onLocationUpdate Stream<LocationFix>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isRunning() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAutoStartSettings() Future<bool>
pendingCacheCount() Future<int>
requestBatteryOptimizationExemption() Future<void>
start({required Duration interval, required Duration maxInterval, required double distanceFilterMeters, required String sendUrl, required String tokenUrl, required String id, Map<String, dynamic> payload = const {}, String? notificationTitle, String? notificationText, String? notificationIcon}) Future<bool>
stop() Future<void>
syncNow({String id = '', Map<String, dynamic> payload = const {}}) Future<bool>
toString() String
A string representation of this object.
inherited
updateNotification({String? title, String? text, String? icon}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance GeohawkPlatform
getter/setter pair